###################################################################################################
# Legislative Organization and Political Representation ###########################################
# Main Analysis File ##############################################################################
# Michael Olson and Jon Rogowski ##################################################################
###################################################################################################

###################################################################################################
# working directory and packages ##################################################################
###################################################################################################

  require(lfe)
  require(ggplot2)
  require(stargazer)
  require(vtable)
  require(interflex)
  require(english)
  require(tidyr)
  require(stringr)
  require(dplyr)

###################################################################################################
# load data #######################################################################################
###################################################################################################

  mc <- read.csv("./analysis_data/mc_main.csv")
    mc <- plyr::rename(mc,replace=c("Issue.Area"="Issue Area"))

###################################################################################################
# descriptive information #########################################################################
###################################################################################################

# number of legislators

  fileConn<-file("./results/n_legs.tex")
  writeLines(format(length(unique(mc$icpsr)),big.mark=","), fileConn)
  close(fileConn)

# number of congresses

  fileConn<-file("./results/n_congs.tex")
  writeLines(as.character(english(length(unique(mc$cong)))), fileConn)
  close(fileConn)

# number of issue areas

  fileConn<-file("./results/n_issues.tex")
  writeLines(as.character(english(length(unique(mc$issue)))), fileConn)
  close(fileConn)

# number of committees

  fileConn<-file("./results/n_comms.tex")
  writeLines(as.character(english(length(unique(mc$committee)))), fileConn)
  close(fileConn)

# histogram by issue area

  ggplot(data=mc,aes(x=adj.score))+
    geom_histogram()+
    xlab("Conservative Vote Probability")+
    ylab("Count")+
    facet_wrap(~`Issue Area`,ncol=3,scales="free")+
    theme_bw()+
    theme(strip.background = element_rect(fill="black"),
          strip.text = element_text(face="bold",color="white"))

  ggsave("./results/facet_hist.jpeg",dpi=600,width=8.5,height=11,units="in")

# scatter plot by issue area    

  ggplot(data=mc,aes(x=rpres,y=adj.score))+
    stat_summary_bin(fun.y='mean',bins=10,color="black",size=3,geom='point')+
    ylab("Conservative Vote Probability")+
    xlab("Republican Presidential Vote Share")+
    facet_wrap(~`Issue Area`,ncol=3)+
    theme_bw()+
    theme(strip.background = element_rect(fill="black"),
          strip.text = element_text(face="bold",color="white"))

  ggsave("./results/facet_scatter.jpeg",dpi=600,width=8.5,height=11,units="in")

# correlation matrix--across issues

  mc_towide <- mc[,c("state","icpsr","cong","Issue Area","adj.score")]
  mc_wide   <- mc_towide %>% spread(`Issue Area`,adj.score)
    # make a wide-form version of the adjusted scores
  
  cor_mat   <- cor(as.matrix(mc_wide[,-which(is.element(colnames(mc_wide),c("state","icpsr","cong")))]),
                   use="pairwise.complete.obs")
  cor_mat[upper.tri(cor_mat,diag=T)] <- ""
  cor_mat_num <- as.data.frame(apply(cor_mat,2,as.numeric))
  cor_mat_num$id <- colnames(cor_mat_num)
    # make a correlation matrix, get rid of the upper triangle
  
  cor_mat_num <- reshape2::melt(cor_mat_num,na.rm=T)
    # melt it back to long form

  # save the total number of correlations
  
  fileConn<-file("./results/n_corrs.tex")
  writeLines(as.character(english(nrow(cor_mat_num))), fileConn)
  close(fileConn)
  
  # save the number over 0.7

  fileConn<-file("./results/n_corrs70.tex")
  writeLines(as.character(english(nrow(cor_mat_num[cor_mat_num$value>0.7,]))), fileConn)
  close(fileConn)
  
  # save the number below 0.5

  fileConn<-file("./results/n_corrs50.tex")
  writeLines(as.character(english(nrow(cor_mat_num[cor_mat_num$value<0.5,]))), fileConn)
  close(fileConn)
  
  # save the lowest correlation

  fileConn<-file("./results/min_corr.tex")
  writeLines(as.character(round(min(cor_mat_num$value),2)), fileConn)
  close(fileConn)
  
  # save the issues that have that lowest correlation

  fileConn<-file("./results/min_corr_issues.tex")
  writeLines(paste(cor_mat_num$id[round(cor_mat_num$value,2)==round(min(cor_mat_num$value),2)],
                   cor_mat_num$variable[round(cor_mat_num$value,2)==round(min(cor_mat_num$value),2)],
                   sep=" and "), fileConn)
  close(fileConn)
  
  # make a correlation matrix figure and save it

    ggplot(data = cor_mat_num, aes(id, variable, fill = value))+
      geom_tile()+
      scale_fill_gradient2(low = "white", high = "black",mid="grey50",
                           midpoint = 0.5, limit = c(0,1), space = "Lab",
                           name="Correlation") +
      xlab("")+ylab("")+
      theme_minimal()+ 
      theme(axis.text.x = element_text(angle = 45, vjust = 1, 
                                       size = 10, hjust = 1))+
      coord_fixed()
  
  ggsave("./results/correlation_matrix.jpeg",dpi=600,width=8,height=6,units="in")
  
# descriptive statistics table

  tab_dat <- mc[,c("adj.score","rpres","on_committee","logstaff","staff_per_member","rep","maj","Issue Area","committee")]
    # keep data we want for summary statistics table
  
  tab_dat$`Issue Area` <- as.factor(tab_dat$`Issue Area`)
  tab_dat$committee <- str_to_title(gsub("_"," ",fixed=T,tab_dat$committee))
  tab_dat[tab_dat$committee=="Energy Commerce","committee"] <- "Energy & Commerce"
  tab_dat[tab_dat$committee=="Educ Labor","committee"] <- "Education & Labor"
  tab_dat[tab_dat$committee=="Ways Means","committee"] <- "Ways & Means"
  tab_dat$committee <- as.factor(tab_dat$committee)
    # we turn issue area and committee into pretty-looking factor variables to play nicely
    # with the sumtable function
  
  sumtable(data=tab_dat,summ.names = c("Obs.","Mean","St. Dev.","Min.","25th","75th","Max"),
           digits=2,fixed.digits = T,
           labels=c("Adjusted CVP",
                    "GOP Presidential Vote Share",
                    "On Committee",
                    "ln(Staff on Committee)",
                    "ln(Staff per Committee Member)",
                    "Republican",
                    "Majority",
                    "Issue Area",
                    "Committee"),
           out="latex",anchor="summary_stats",
           file="./results/summary_statistics.tex")

# now we want to produce a table that gives a breakdown of our adjusted scores
# by issue area; this is also a strength of the sumtable function

  issue_area_dat <- tab_dat[,c("Issue Area","adj.score")]
    # only keep

  sumtable(data=issue_area_dat,group=c("Issue Area"),group.long=T,
           labels="Adjusted CVP",out="latex",anchor="summary_issues",
           file="./results/summary_issues.tex",
           title="Summary Statistics for Adjusted CVP by Issue Area")

  Sys.sleep(3)
    # brief pause to let the file write before we read it back in

  sumissues <- readChar("./results/summary_issues.tex", 
                        file.info("./results/summary_issues.tex")$size)
    # the shortcoming of the sumtable function is no flexibility on font sizes
    # so to make things fit we read the file back in and make some changes to the 
    # text string to reduce the size, then re-output it

  sumissues <- gsub("\\centering","\\centering \\tiny",fixed=T,sumissues)
  sumissues <- gsub(" &  &  &  &  &  &  &  \\\\"," &  &  &  &  &  &  &  \\\\ [-1ex]",fixed=T,sumissues)
  
  Sys.sleep(3)
  
  cat(sumissues, sep = '\n', file = "./results/summary_issues.tex")

# now we want to create some descriptive statistics for frequency of switching on
# and off committees

  mc_comm_unique <- mc %>% distinct(icpsr,committee,cong,on_committee)
    # start by creating a legislator-by-committee-by-congress dataset
    # just leave on-committee in here because we're going to want it and
    # it doesn't change anything
  
  mc_comm_unique$icpsr_committee <- paste(mc_comm_unique$icpsr,mc_comm_unique$committee,sep="_")
  mc_comm_unique <- dplyr::arrange(mc_comm_unique,icpsr_committee,cong)
    # create a legislator-committee identifier and sort by that

  mc_comm_unique <- DataCombine::slide(mc_comm_unique,Var="on_committee",GroupVar="icpsr_committee",TimeVar="cong",NewVar="on_committee_lag",slideBy=-1)
    # do a lag of the on_committee indicator 

  mc_comm_unique$committee_change <- abs(mc_comm_unique$on_committee-mc_comm_unique$on_committee_lag)
    # create a variable that just captures whether a legislator's status on a committee
    # has changed; in either direction

  mc_tot_changes <- mc_comm_unique %>% group_by(icpsr) %>% summarise(tot_changes = sum(committee_change,na.rm=T))
    # now sum up all the changes over the MC's careers

  mc_comm_unique$icpsr_committee <- NULL
  mc <- left_join(mc,mc_comm_unique)
    # add the committee change back in to the main dataset
    # drop the icpsr_committee column because that actually already exists there

  # average number of committee changes for a given legislator
  
    fileConn<-file("./results/mean_changes.tex")
    writeLines(format(round(mean(mc_tot_changes$tot_changes),3),nsmall=3), fileConn)
    close(fileConn)
  
  # proportion of legislators with at least one committee change
  
    fileConn<-file("./results/prop_w_change.tex")
    writeLines(paste(format(100*round(nrow(mc_tot_changes[mc_tot_changes$tot_changes>0,])/nrow(mc_tot_changes),3),nsmall=1),"\\%",sep=""), fileConn)
    close(fileConn)
  
  # proportion of legislators on a committee who are transfers on
  
    fileConn<-file("./results/prop_that_changed.tex")
    writeLines(paste(format(round(100*unlist(prop.table(table(mc_comm_unique[mc_comm_unique$on_committee==1,"committee_change"]))["1"]),1),nsmall=1),"\\%",sep=""), fileConn)
    close(fileConn)
  
  # number of legislator-sessions with a committee change
  
    fileConn<-file("./results/nrow_wchange.tex")
    writeLines(format(nrow(mc[mc$committee_change==1 & !is.na(mc$committee_change),]),nsmall=1,big.mark=","), fileConn)
    close(fileConn)

# now we want to look at some committee staff descriptives
    
  # load the yearly crs data
      
    crs_yearly <- read.csv("./analysis_data/crs_yearly.csv")
      crs_yearly$n_staff <- as.numeric(crs_yearly$n_staff)
      
    crs_disag <- crs_yearly
    crs_yearly <- crs_yearly %>% group_by(year) %>% summarise(n_staff=sum(n_staff,na.rm=T))
      # create a version that has annual sums, but retain the separate one
  
  # write out the number of staff in the first year we have this data for

    fileConn<-file("./results/x77_staff.tex")
    writeLines(format(crs_yearly$n_staff[crs_yearly$year==1977],nsmall=0,big.mark=","), fileConn)
    close(fileConn)

  # write out the max committee value and the year that it happens
    
    fileConn<-file("./results/max_staff.tex")
    writeLines(format(max(crs_yearly$n_staff,na.rm=T),nsmall=0,big.mark=","), fileConn)
    close(fileConn)

    fileConn<-file("./results/max_staff_year.tex")
    writeLines(format(crs_yearly$year[crs_yearly$n_staff==max(crs_yearly$n_staff,na.rm=T) & !is.na(crs_yearly$n_staff)],nsmall=0,big.mark=""), fileConn)
    close(fileConn)

  # write out the min committee value and the year that it happens

    fileConn<-file("./results/min_staff.tex")
    writeLines(format(min(crs_yearly$n_staff,na.rm=T),nsmall=0,big.mark=","), fileConn)
    close(fileConn)
    
    fileConn<-file("./results/min_staff_year.tex")
    writeLines(format(crs_yearly$year[crs_yearly$n_staff==min(crs_yearly$n_staff,na.rm=T) & !is.na(crs_yearly$n_staff)],nsmall=0,big.mark=""), fileConn)
    close(fileConn)
    
  # write out the range of values for the appropriations committee

    crs_app <- crs_disag[crs_disag$Committee=="appropriations",]
    
    fileConn<-file("./results/min_approp.tex")
    writeLines(format(min(crs_app$n_staff,na.rm=T),nsmall=0,big.mark=""), fileConn)
    close(fileConn)
    
    fileConn<-file("./results/max_approp.tex")
    writeLines(format(max(crs_app$n_staff,na.rm=T),nsmall=0,big.mark=""), fileConn)
    close(fileConn)

  # and for the agriculture committee

    crs_ag <- crs_disag[crs_disag$Committee=="agriculture",]
    
    fileConn<-file("./results/min_ag.tex")
    writeLines(format(min(crs_ag$n_staff,na.rm=T),nsmall=0,big.mark=""), fileConn)
    close(fileConn)
    
    fileConn<-file("./results/max_ag.tex")
    writeLines(format(max(crs_ag$n_staff,na.rm=T),nsmall=0,big.mark=""), fileConn)
    close(fileConn)

# now we want to explore whether folks on and off commmittees behave differently
# are members of committees more homogeneous? more moderate?

  # first, for each issue and congress, look at extremism and spread of ideal points
  # for those both on and off committees
        
    comm_ags <- mc %>% group_by(cong_issue,on_committee) %>% summarise(extremism = mean(abs(adj.score),na.rm=T),
                                                                       spread    = sd(adj.score,na.rm=T))
    
  # then get some measures of central tendency across those committees

    comm_ags <- comm_ags %>% group_by(on_committee) %>% summarise(med_extremism=median(extremism),med_spread=median(spread),
                                                                  mean_extremism=mean(extremism),mean_spread=mean(spread))
    
    
  # mean extremism of those on committees
    
    fileConn<-file("./results/on_mean_ext.tex")
    writeLines(format(round(comm_ags$mean_extremism[comm_ags$on_committee==1],3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
  # mean extremism of those off committees

    fileConn<-file("./results/off_mean_ext.tex")
    writeLines(format(round(comm_ags$mean_extremism[comm_ags$on_committee==0],3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
  # median extremism of those on committees

    fileConn<-file("./results/on_med_ext.tex")
    writeLines(format(round(comm_ags$med_extremism[comm_ags$on_committee==1],3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

  # median extremism for those off committees  
    
    fileConn<-file("./results/off_med_ext.tex")
    writeLines(format(round(comm_ags$med_extremism[comm_ags$on_committee==0],3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
  # mean spread for those on committees

    fileConn<-file("./results/on_mean_spread.tex")
    writeLines(format(round(comm_ags$mean_spread[comm_ags$on_committee==1],3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
  # mean spread for those off committees

    fileConn<-file("./results/off_mean_spread.tex")
    writeLines(format(round(comm_ags$mean_spread[comm_ags$on_committee==0],3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
  # median spread for those on committees

    fileConn<-file("./results/on_med_spread.tex")
    writeLines(format(round(comm_ags$med_spread[comm_ags$on_committee==1],3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
  # median spread for those off committees

    fileConn<-file("./results/off_med_spread.tex")
    writeLines(format(round(comm_ags$med_spread[comm_ags$on_committee==0],3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

# are minority members on fewer committees?

  # n_comms <-  mc[!is.na(mc$maj),] %>% distinct(committee,icpsr,cong,.keep_all=T) %>% 
  #   group_by(icpsr,maj,cong) %>% 
  #   summarise(n_committees=sum(on_committee)) %>% 
  #   group_by(maj) %>% summarise(mean_comms=mean(n_committees))
  #   # so this code limits the data to partisans
  #   # then makes sure we're at teh member-committee level 
  #   # (so dropping duplicate issues within committee)
  #   # then sums up the number of committees legislators are on
  #   # by legislator and congress (retaining majority party status)
  #   # then finds the mean by whether or not they're in the majority

###################################################################################################
# analyses ########################################################################################
###################################################################################################  
  
########################################
# iterating over committee years #######
########################################

  mc$comm_year <- paste(mc$committee,mc$year)
  regout <- vector()
    # make a committee-year variable
    # and a vector to hold our output
  
  for(j in 1:length(unique(mc$comm_year))){
      # loop over all of the unique committee years
    
    folks_on_committee <- unique(mc$cong_icpsr[mc$comm_year==sort(unique(mc$comm_year))[j] & mc$on_committee==1])
      # pull out the folks who are on that committee
    
    bit <- mc[is.element(mc$cong_icpsr,folks_on_committee),]
      # then find them for all the committees that they're on -- not just this one
    
    bit$treat <- 0
    bit[bit$comm_year==sort(unique(mc$comm_year))[j],"treat"] <- 1
    bit <- bit[bit$on_committee==0 | bit$treat==1,]
      # then we make a new treatment variable that's a value of one if they're on this
      # particular committee; we drop any MC-committee combo where they are on that committee
      # this way we're comparing legislators on the given committee to those same legislators
      # on issues for which they are not on the committees
    
    regout[j] <- summary(felm(adj.score~rpres*treat+maj|0|0|icpsr,data=bit))$coefficients["rpres:treat",1]
      # then we regress adjusted score on an interaction between presidential vote share and
      # being on that committee, plus an indicator for majority party; we save the coefficient
      # on the interaction.
    
  }
  
  regout <- as.data.frame(cbind(sort(unique(mc$comm_year)),regout))
  colnames(regout) <- c("comm_year","estimate")
    # make a dataframe of the output by binding the committees and the regression
    # output together
  
  regout$committee <- gsub("[^(a-z)(\\_)]","",regout$comm_year)
  regout$year <- as.numeric(gsub("[^(0-9)]","",regout$comm_year))
  regout$estimate <- as.numeric(regout$estimate) 
    # split the comm year variable into committee and year variables
    # make sure the estimate variable is numeric
  
  regout$comm_type <- "Distributive"
  regout[is.element(regout$committee,c("banking","energy_commerce","foreign_affairs")),"comm_type"] <- "Policy"
  regout[is.element(regout$committee,c("appropriations","educ_labor","ways_means")),"comm_type"] <- "Other"
    # create "types" for the committees -- distributive, policy, and other

# descriptives
  
  # median coefficient across all regressions

    fileConn<-file("./results/iterative_median.tex")
    writeLines(format(round(median(regout$estimate),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
  # mean coefficient across all regressions
  
    fileConn<-file("./results/iterative_mean.tex")
    writeLines(format(round(mean(regout$estimate),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

  # histogram of the coefficients
  
    ggplot(regout,aes(x=estimate))+
      geom_density(fill="grey60")+
      theme_minimal()+
      xlab("Interaction Coefficient Estimates")+
      ylab("Density")+
      geom_vline(xintercept=0,linetype=2,size=2,colour="black")
    
    ggsave("./results/iterative_distribution.jpeg",width=6,height=3,units="in",dpi=600)

  # plot the estimates over time
  
    ot <- aggregate(estimate~year,data=regout,FUN=median)
      # first find the median value by year
    
    ggplot(ot,aes(x=year,y=estimate))+
      geom_hline(yintercept=0,linetype=2,size=2,colour="black")+
      geom_point(size=3,colour="black")+
      geom_line(size=1.25,colour="black",se=F)+
      xlab("Year")+
      ylab("Mean Interaction Coefficient Estimate")+
      theme_minimal()
    
    ggsave("./results/iterative_ot.jpeg",width=6,height=3,units="in",dpi=600)

# now do some similar info/types of plots splitting out by different committee types

  # first a histogram
  
    ggplot(regout,aes(x=estimate,group=comm_type,fill=comm_type,colour=comm_type))+
      geom_density(alpha=0.6)+
      scale_fill_grey(start=0.2,end=0.8)+
      scale_colour_grey(start=0.2,end=0.8)+
      theme_minimal()+
      xlab("Interaction Coefficient Estimates")+
      ylab("Density")+
      labs(fill="Committee Type: ",colour="Committee Type: ")+
      geom_vline(xintercept=0,linetype=2,size=2,colour="black")+
      theme(legend.position = "bottom")
    
    ggsave("./results/iterative_type.jpeg",width=6,height=3,units="in",dpi=600)
    
  # median for the distributive committees

    fileConn<-file("./results/iterative_median_dist.tex")
    writeLines(format(round(median(regout$estimate[regout$comm_type=="Distributive"]),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

  # mean for the distributive committees

    fileConn<-file("./results/iterative_mean_dist.tex")
    writeLines(format(round(mean(regout$estimate[regout$comm_type=="Distributive"]),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

  # median for the policy committees

    fileConn<-file("./results/iterative_median_policy.tex")
    writeLines(format(round(median(regout$estimate[regout$comm_type=="Policy"]),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

  # mean for the policy committees

    fileConn<-file("./results/iterative_mean_policy.tex")
    writeLines(format(round(mean(regout$estimate[regout$comm_type=="Policy"]),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

########################################
# iterating over issue-years ###########
########################################
    
  # here we'll do a similar exercise, but instead of iterating over committee
  # years and comparing committee members to themselves but on other issues,
  # we'll pull out everyone for a specific issue, and compare across those on
  # and off committees relevant to that issue

  regout_issue <- vector()
    # create a vector to hold our results
  
  for(j in 1:length(unique(mc$cong_issue))){
      # loop over the different congress-issues
    
    bit_issue <- mc[is.element(mc$cong_issue,sort(unique(mc$cong_issue))[j]),]
      # pull out everyone for that particular congress issue
      # no need to drop anyone this time, because everyone should
      # only be in here once
    
    bit_issue$treat <- bit_issue$on_committee
      # just to be consistent, create a variable called treat
    
    regout_issue[j] <- summary(felm(adj.score~rpres*treat+maj|0|0|icpsr,data=bit_issue))$coefficients["rpres:treat",1]
      # run the same regression as above

  }
  
  regout_issue <- as.data.frame(cbind(sort(unique(mc$comm_year)),regout_issue))
  colnames(regout_issue) <- c("comm_year","estimate")
  regout_issue$committee <- gsub("[^(a-z)(\\_)]","",regout_issue$comm_year)
  regout_issue$year <- as.numeric(gsub("[^(0-9)]","",regout_issue$comm_year))
  regout_issue$estimate <- as.numeric(regout_issue$estimate) 
    # create the data frame, committee and year variables, and make sure
    # estimate is numeric, as above
  
  regout_issue$comm_type <- "Distributive"
  regout_issue[is.element(regout_issue$committee,c("banking","energy_commerce","foreign_affairs")),"comm_type"] <- "Policy"
  regout_issue[is.element(regout_issue$committee,c("appropriations","educ_labor","ways_means")),"comm_type"] <- "Other"
    # assign the same committee types as above

# descriptives

  # overall median and mean
  
    fileConn<-file("./results/iterative_median_issue.tex")
    writeLines(format(round(median(regout_issue$estimate),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

    fileConn<-file("./results/iterative_mean_issue.tex")
    writeLines(format(round(mean(regout_issue$estimate),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

  # histogram of the estimates
  
    ggplot(regout_issue,aes(x=estimate))+
      geom_density(fill="grey60")+
      theme_minimal()+
      xlab("Interaction Coefficient Estimates")+
      ylab("Density")+
      geom_vline(xintercept=0,linetype=2,size=2,colour="black")
    
    ggsave("./results/iterative_distribution_issue.jpeg",width=6,height=3,units="in",dpi=600)

  # over time plot
  
    ot_issue <- aggregate(estimate~year,data=regout_issue,FUN=median)
  
    ggplot(ot_issue,aes(x=year,y=estimate))+
      geom_hline(yintercept=0,linetype=2,size=2,colour="black")+
      geom_point(size=3,colour="black")+
      geom_line(size=1.25,colour="black",se=F)+
      xlab("Year")+
      ylab("Mean Interaction Coefficient Estimate")+
      theme_minimal()
    
    ggsave("./results/iterative_ot_issue.jpeg",width=6,height=3,units="in")

# now similar information for different types of committees
    
  # histogram

    ggplot(regout_issue,aes(x=estimate,group=comm_type,fill=comm_type,colour=comm_type))+
      geom_density(alpha=0.6)+
      scale_fill_grey(start=0.2,end=0.8)+
      scale_colour_grey(start=0.2,end=0.8)+
      theme_minimal()+
      xlab("Interaction Coefficient Estimates")+
      ylab("Density")+
      labs(fill="Committee Type: ",colour="Committee Type: ")+
      geom_vline(xintercept=0,linetype=2,size=2,colour="black")+
      theme(legend.position = "bottom")

    ggsave("./results/iterative_type_issue.jpeg",width=6,height=3,units="in",dpi=600)
    
  # medians and means by distributive and policy  

    fileConn<-file("./results/iterative_median_dist_issue.tex")
    writeLines(format(round(median(regout_issue$estimate[regout_issue$comm_type=="Distributive"]),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
    fileConn<-file("./results/iterative_mean_dist_issue.tex")
    writeLines(format(round(mean(regout_issue$estimate[regout_issue$comm_type=="Distributive"]),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
    fileConn<-file("./results/iterative_median_policy_issue.tex")
    writeLines(format(round(median(regout_issue$estimate[regout_issue$comm_type=="Policy"]),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)
    
    fileConn<-file("./results/iterative_mean_policy_issue.tex")
    writeLines(format(round(mean(regout_issue$estimate[regout_issue$comm_type=="Policy"]),3),nsmall=3,big.mark=""), fileConn)
    close(fileConn)

###################################################################################################
# Main Results ####################################################################################
###################################################################################################

# make main table

  dist <- felm(adj.score~rpres*on_committee|distid_issue+cong_issue|0|icpsr ,data=mc)
  dist_party <- felm(adj.score~rpres*on_committee+rep|distid_issue+cong_issue|0|icpsr ,data=mc)
  memb <- felm(adj.score~rpres*on_committee|icpsr_issue+cong_issue|0|icpsr ,data=mc)
  memb2 <- felm(adj.score~rpres*on_committee-rpres|icpsr_issue+cong_icpsr|0|icpsr ,data=mc)
  memb3 <- felm(adj.score~rpres*on_committee-rpres|icpsr_issue+cong_issue+cong_icpsr|0|icpsr ,data=mc)

  tab_sg <- stargazer(memb,memb2,memb3,dist,dist_party,
                      dep.var.labels = c("Adjusted Conservative Vote Probability"),
                      title="Committee Service and Ideological Responsiveness",
                      label="main",
                      covariate.labels = c("Republican Presidential Vote Share",
                                           "On Committee",
                                           "Republican",
                                           "Rep. Pres. Vote Share $\\times$ On Comm."),
                      add.lines = list(c("Member-by-Issue Fixed Effects","\\checkmark","\\checkmark","\\checkmark","",""),
                                       c("District-by-Issue Fixed Effects","","","","\\checkmark","\\checkmark"),
                                       c("Congress-by-Issue Fixed Effects","\\checkmark","","\\checkmark","\\checkmark","\\checkmark"),
                                       c("Congress-by-Member Fixed Effects","","\\checkmark","\\checkmark","",""),
                                       c("No. Unit FEs",
                                         format(length(unique(memb$fe$icpsr_issue)),big.mark=","),
                                         format(length(unique(memb2$fe$icpsr_issue)),big.mark=","),
                                         format(length(unique(memb3$fe$icpsr_issue)),big.mark=","),
                                         format(length(unique(dist$fe$distid_issue)),big.mark=","),
                                         format(length(unique(dist_party$fe$distid_issue)),big.mark=",")),
                                       c("No. Clusters",
                                         format(length(unique(memb$clustervar$icpsr)),big.mark=","),
                                         format(length(unique(memb2$clustervar$icpsr)),big.mark=","),
                                         format(length(unique(memb3$clustervar$icpsr)),big.mark=","),
                                         format(length(unique(dist$clustervar$icpsr)),big.mark=","),
                                         format(length(unique(dist_party$clustervar$icpsr)),big.mark=","))),
                      keep.stat = c("n"),
                      star.cutoffs = c(0.10,0.05),star.char = c("*","**"),table.placement="!ht",
                      notes.append = FALSE,notes.label = "",column.sep.width="0pt",
                      table.layout ="-ld-#-t-as-n",
                      notes="\\parbox[t]{0.95\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                       standard errors clustered on legislators in parentheses. Observations are at the MC-by-issue-by-Congress level.
                        $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")

  cat(tab_sg, sep = '\n', file = "./results/main.tex")
  
# make a figure that captures this relationship
# because the main variable of interest is an interaction we can plot it
# using interflex

  memb_fig <- interflex(estimator="binning",
                        data=mc,Y="adj.score",D="on_committee",X="rpres",
                        FE=c("icpsr_issue","cong_issue"),cl="distid",
                        vcov.type="cluster",na.rm=T)

  ggsave(filename="./results/main_interflex.jpeg",
         plot=plot(memb_fig,
                   xlab="Republican Presidential Vote Share",
                   ylab="Marginal Effect of Committee Service",
                   theme.bw = T,bin.labs=F),
         dpi=600,
         width=8,height=6,units="in")
  
#################################  
# other in-text results #########
#################################
  
# heterogeneity by committee type
  
  mc$policy <- 0
  mc[is.element(mc$committee,c("appropriations","educ_labor","ways_means")),"policy"] <- 0.5
  mc[is.element(mc$committee,c("banking","energy_commerce","foreign_affairs")),"policy"] <- 1
    # first create an "indicator" for whether a committee is policy or distributive
    # things that our source classify as "other" we mark as a 0.5

  memb_party_int_dist <- felm(adj.score~rpres*on_committee*I(1-policy)-I(1-policy)|factor(icpsr_issue)+factor(cong_issue)|0|icpsr,data=mc[mc$policy!=0.5,])
  memb_party_int_pol <- felm(adj.score~rpres*on_committee*policy-policy|factor(icpsr_issue)+factor(cong_issue)|0|icpsr,data=mc[mc$policy!=0.5,])
    # next we run really the same regression, but twice -- with opposite codings of the policy variable. We do this because triple-interactions
    # are a nightmare; doing it this way means that the interaction between rpres and on_committee in the first model is going to give that
    # relationship on policy committees, and the same value in the second model will give it off committees.
  
  fileConn<-file("./results/type_p.tex")
  writeLines(format(round(summary(memb_party_int_pol)$coefficients["rpres:on_committee:policy","Pr(>|t|)"],3),nsmall=3,big.mark=""), fileConn)
  close(fileConn)
    # first just pull out the p-value on the triple-interaction; this triple interaction gives whether the responsiveness varies across
    # committee type. The answer here is "yes."
  
  dist_base <- summary(memb_party_int_pol)$coefficients["rpres",c("Estimate","Cluster s.e.")]
  pol_base <- summary(memb_party_int_dist)$coefficients["rpres",c("Estimate","Cluster s.e.")]
    # dist_base gives the responsiveness off committee for distributive committees
    # pol_base gives the responsiveness off committee for policy committees 
    # the labeling is a bit flipped because the models are named based on what's being interacted
    # but as a result the base terms represent the *absence* of that interaction
  
  dist_int <- summary(memb_party_int_pol)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
  pol_int <- summary(memb_party_int_dist)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
    # same idea here -- pull out the two-way interactions
  
  dist_me  <- c(dist_base["Estimate"]+dist_int["Estimate"],
                sqrt(dist_base["Cluster s.e."]^2+dist_int["Cluster s.e."]^2+2*memb_party_int_pol$clustervcv["rpres:on_committee","rpres"]))
  pol_me  <- c(pol_base["Estimate"]+pol_int["Estimate"],
               sqrt(pol_base["Cluster s.e."]^2+pol_int["Cluster s.e."]^2+2*memb_party_int_dist$clustervcv["rpres:on_committee","rpres"]))
    # now calculate the marginal effects for each group -- sum up the coefficients, calculate the standard errors
    # these are going to give the marginal effects for being on a committee
  
  type_dat <- as.data.frame(rbind(dist_base,pol_base,dist_int,pol_int,dist_me,pol_me))
  rownames(type_dat) <- NULL
  type_dat$type <- rep(c("Distributive","Policy"),3)
  type_dat$qoi   <- c(rep("Off Committee",2),rep("Difference",2),rep("On Committee",2))
  type_dat$qoi <- factor(type_dat$qoi,levels=c("Off Committee","On Committee","Difference"))
    # bind it all together, add some labels
  
  # make a plot that conveys all of this info!
  
    ggplot(data=type_dat,
           aes(x=qoi,y=Estimate,
               ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`,
               colour=type,group=type))+
      geom_hline(yintercept=0,size=1.25,colour="grey40",linetype=2)+
      geom_point(position=position_dodge(width=0.5),size=4)+
      geom_linerange(position=position_dodge(width=0.5),size=1.25)+
      geom_linerange(position=position_dodge(width=0.5),size=2,
                     aes(x=qoi,
                         ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`,
                         colour=type,group=type))+
      scale_colour_grey(start=0.2,end=0.6)+
      xlab("")+
      ylab("Marginal Effect of District GOP Vote Share")+
      labs(color="Committee Type:")+
      theme_minimal()+
      theme(legend.position = "bottom",
            legend.title = element_text(face="bold",size=10),
            legend.text = element_text(face="bold",size=10),
            axis.text = element_text(size=10))
  
  ggsave("./results/type_interaction.jpeg",width=6,height=4,dpi=600)
  
#####################################
# effects of duration of service ####
#####################################  
  
  duration_memb <- felm(adj.score~rpres*(congs_served+on_committee)|icpsr_issue+cong_issue|0|icpsr,data=mc)
  duration_memb2 <- felm(adj.score~rpres*(congs_served+on_committee)-rpres|icpsr_issue+cong_icpsr|0|icpsr,data=mc)
  duration_memb3 <- felm(adj.score~rpres*(congs_served+on_committee)-rpres|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc)
  duration_dist <- felm(adj.score~rpres*(congs_served+on_committee)|distid_issue+cong_issue|0|icpsr,data=mc)
  duration_dist_party <- felm(adj.score~rpres*(congs_served+on_committee)+rep|distid_issue+cong_issue|0|icpsr,data=mc)
    # these models all add the previously made variable for congs served to the interaction; still only two-way
  
  tab_duration_sg <- stargazer(duration_memb,duration_memb2,duration_memb3,duration_dist,duration_dist_party,
                               dep.var.labels = c("Adjusted Conservative Vote Probability"),
                               title="Length and Durability of Committee Service and Ideological Responsiveness",
                               label="main_duration",
                               covariate.labels = c("Republican Presidential Vote Share",
                                                    "Committee Tenure",
                                                    "On Committee",
                                                    "Republican",
                                                    "Rep. Vote Share $\\times$ Committee Tenure",
                                                    "Rep. Vote Share $\\times$ On Committee"),
                               add.lines = list(c("Member-by-Issue Fixed Effects","\\checkmark","\\checkmark","\\checkmark","",""),
                                                c("District-by-Issue Fixed Effects","","","","\\checkmark","\\checkmark"),
                                                c("Congress-by-Issue Fixed Effects","\\checkmark","","\\checkmark","\\checkmark","\\checkmark"),
                                                c("Congress-by-Member Fixed Effects","","\\checkmark","\\checkmark","",""),
                                                c("No. Unit FEs",
                                                  format(length(unique(duration_memb$fe$icpsr_issue)),big.mark=","),
                                                  format(length(unique(duration_memb2$fe$icpsr_issue)),big.mark=","),
                                                  format(length(unique(duration_memb3$fe$icpsr_issue)),big.mark=","),
                                                  format(length(unique(duration_dist$fe$distid_issue)),big.mark=","),
                                                  format(length(unique(duration_dist_party$fe$distid_issue)),big.mark=",")),
                                                c("No. Clusters",
                                                  format(length(unique(duration_memb$clustervar$icpsr)),big.mark=","),
                                                  format(length(unique(duration_memb2$clustervar$icpsr)),big.mark=","),
                                                  format(length(unique(duration_memb3$clustervar$icpsr)),big.mark=","),
                                                  format(length(unique(duration_dist$clustervar$icpsr)),big.mark=","),
                                                  format(length(unique(duration_dist_party$clustervar$icpsr)),big.mark=","))),
                               keep.stat = c("n"),#font.size = "footnotesize",
                               star.cutoffs = c(0.10,0.05),star.char = c("*","**"),no.space=T,
                               notes.append = FALSE,notes.label = "",column.sep.width="0pt",
                               table.layout ="-ld-#-t-as-n",
                               notes="\\parbox[t]{0.975\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                     standard errors clustered on legislators in parentheses. Observations are at the MC-by-issue-by-Congress level. 
                      $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")
  
  cat(tab_duration_sg, sep = '\n', file = "./results/main_duration.tex")
  
  
###################################################################################################
# Committee Staff as a Moderator ##################################################################
###################################################################################################
  
# use interflex to make a figure that estimates how the interaction between rpres and on_comittee
# (which we've made a separate variable -- int -- for) across levels of staffing

  nstaff_binning <- interflex(estimator="binning",data=mc,
                              Y="adj.score",
                              D="int",
                              X="logstaff",
                              Z=c("on_committee","rpres","staff_com","staff_rpres"),
                              FE=c("icpsr_issue","cong_issue"),
                              full.moderate = F,
                              na.rm=T,CI=T,vcov.type ="cluster",
                              cl="distid",
                              nbins=3)
    # note that we had to put all the base terms in the Z vector manually
    # this is to ensure that the model being estimated has all of those,
    # since we're dealing with a triple interaction; the results of th
    # linear output of this do match the regression below
  
  ggsave(filename="./results/binning_staff.jpeg",
         plot=plot(nstaff_binning,
                   xlab="ln(Committee Staff)",
                   ylab="Estimate of Interaction Between Committee and GOP Vote Share",
                   theme.bw = T,bin.labs=F)+theme(plot.margin = unit(c(1, 1, 1, 1), "cm")),
         width=12,height=8,units="in",dpi=600)
    # plot the results

  
  dist_party_staff <- felm(adj.score~rpres*on_committee*logstaff+rep-logstaff|distid_issue+cong_issue|0|icpsr,data=mc)
  memb_staff <- felm(adj.score~rpres*on_committee*logstaff-logstaff|icpsr_issue+cong_issue|0|icpsr,data=mc)
  memb3_staff <- felm(adj.score~rpres*on_committee*logstaff-rpres-logstaff|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc)
  
  dist_party_staff2 <- felm(adj.score~rpres*on_committee*staff_per_member+rep-staff_per_member|distid_issue+cong_issue|0|icpsr,data=mc)
  memb_staff2 <- felm(adj.score~rpres*on_committee*staff_per_member-staff_per_member|icpsr_issue+cong_issue|0|icpsr,data=mc)
  memb3_staff2 <- felm(adj.score~rpres*on_committee*staff_per_member-rpres-staff_per_member|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc)
    # we trim the particular models down a bit here just for space's sake
    # the two sets of models use the log of the number of staff and the number of staff per member, respectively
    # note that the staff measures don't vary within congress-issue, so we drop them from the analysis
  
  tab_staff_sg <- stargazer(memb_staff,memb3_staff,dist_party_staff,memb_staff2,memb3_staff2,dist_party_staff2,
                            dep.var.labels = c("Adjusted Conservative Vote Probability"),
                            title="Committee Service and Ideological Responsiveness, Accounting for Committee Staffing",
                            label="staff",
                            covariate.labels = c("Republican Presidential Vote Share",
                                                 "On Committee",
                                                 "Republican",
                                                 "Rep. Vote Share $\\times$ On Comm.",
                                                 "Rep. Vote Share $\\times$ ln(Staff)",
                                                 "On Committee $\\times$ ln(Staff)",
                                                 "Rep. Vote Share $\\times$ On Comm. $\\times$ ln(Staff)",
                                                 "Rep. Vote Share $\\times$ ln(Staff per Member)",
                                                 "On Committee $\\times$ ln(Staff per Member)",
                                                 "Rep. Vote Share $\\times$ On Comm. $\\times$ ln(Staff P.M.)"),
                            add.lines = list(c("Member-by-Issue Fixed Effects","\\checkmark","\\checkmark","","\\checkmark","\\checkmark",""),
                                             c("District-by-Issue Fixed Effects","","","\\checkmark","","","\\checkmark"),
                                             c("Congress-by-Issue Fixed Effects","\\checkmark","\\checkmark","\\checkmark","\\checkmark","\\checkmark","\\checkmark"),
                                             c("Congress-by-Member Fixed Effects","","\\checkmark","","","\\checkmark",""),
                                             c("No. Unit FEs",
                                               format(length(unique(memb_staff$fe$icpsr_issue)),big.mark=","),
                                               format(length(unique(memb3_staff$fe$icpsr_issue)),big.mark=","),
                                               format(length(unique(dist_party_staff$fe$distid_issue)),big.mark=","),
                                               format(length(unique(memb_staff2$fe$icpsr_issue)),big.mark=","),
                                               format(length(unique(memb3_staff2$fe$icpsr_issue)),big.mark=","),
                                               format(length(unique(dist_party_staff2$fe$distid_issue)),big.mark=",")),
                                             c("No. Clusters",
                                               format(length(unique(memb_staff$clustervar$icpsr)),big.mark=","),
                                               format(length(unique(memb3_staff$clustervar$icpsr)),big.mark=","),
                                               format(length(unique(dist_party_staff$clustervar$icpsr)),big.mark=","),
                                               format(length(unique(memb_staff2$clustervar$icpsr)),big.mark=","),
                                               format(length(unique(memb3_staff2$clustervar$icpsr)),big.mark=","),
                                               format(length(unique(dist_party_staff2$clustervar$icpsr)),big.mark=","))),
                            keep.stat = c("n"),
                            star.cutoffs = c(0.10,0.05),star.char = c("*","**"),table.placement="!ht",
                            notes.append = FALSE,notes.label = "",column.sep.width="0pt",
                            table.layout ="-ld-#-t-as-n",font.size="footnotesize",no.space=T,
                            notes="\\parbox[t]{\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                     standard errors clustered on legislators in parentheses. Observations are at the MC-by-issue-by-Congress level.
                      $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")
  
  cat(tab_staff_sg, sep = '\n', file = "./results/staff.tex")
  
###################################################################################################
# Robustness Checks ###############################################################################
###################################################################################################

###########################
# parallel trends test ####
###########################

  memb_l <- felm(adj.score~rpres*(on_committee+on_committee_lead)|icpsr_issue+cong_issue|0|icpsr,data=mc)
  memb3_l <- felm(adj.score~rpres*(on_committee+on_committee_lead)-rpres|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc)
  memb_ll <- felm(adj.score~rpres*(on_committee+on_committee_lead+on_committee_lag)|icpsr_issue+cong_issue|0|icpsr,data=mc)
  memb3_ll <- felm(adj.score~rpres*(on_committee+on_committee_lead+on_committee_lag)-rpres|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc)
  memb_lll <- felm(adj.score~rpres*(on_committee+on_committee_lead+on_committee_lag+on_committee_lead2+on_committee_lag2)|icpsr_issue+cong_issue|0|icpsr,data=mc)
  memb3_lll <- felm(adj.score~rpres*(on_committee+on_committee_lead+on_committee_lag+on_committee_lead2+on_committee_lag2)-rpres|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc)
    # we stick to our base model and the one with the most statistical control (and we stick to member models, since they're most central to our analysis)
    # for each of these we add 1, 2, or 4 lags/leads of "on_committee" to the model; first just one lead, then a lag and a lead, then two of each.

  tab_ll_sg <- stargazer(memb_l,memb3_l,memb_ll,memb3_ll,memb_lll,memb3_lll,
                         dep.var.labels = c("Adjusted Conservative Vote Probability"),
                         title="Parallel Trends: Committee Service and Ideological Responsiveness",
                         label="main_ll",
                         covariate.labels = c("Republican Presidential Vote Share",
                                              "On Committee",
                                              "On Committee (t+1)",
                                              "On Committee (t-1)",
                                              "On Committee (t+2)",
                                              "On Committee (t-2)",
                                              "Rep. Pres. Vote Share $\\times$ On Committee",
                                              "Rep. Pres. Vote Share $\\times$ On Committee (t+1)",
                                              "Rep. Pres. Vote Share $\\times$ On Committee (t-1)",
                                              "Rep. Pres. Vote Share $\\times$ On Committee (t+2)",
                                              "Rep. Pres. Vote Share $\\times$ On Committee (t-2)"),
                         add.lines = list(c("Member-by-Issue Fixed Effects","\\checkmark","\\checkmark","\\checkmark","\\checkmark","\\checkmark","\\checkmark"),
                                          c("Congress-by-Issue Fixed Effects","\\checkmark","\\checkmark","\\checkmark","\\checkmark","\\checkmark","\\checkmark","\\checkmark"),
                                          c("Congress-by-Member Fixed Effects","","\\checkmark","","\\checkmark","","\\checkmark"),
                                          c("No. Unit FEs",
                                            format(length(unique(memb_l$fe$icpsr_issue)),big.mark=","),
                                            format(length(unique(memb3_l$fe$icpsr_issue)),big.mark=","),
                                            format(length(unique(memb_ll$fe$icpsr_issue)),big.mark=","),
                                            format(length(unique(memb3_ll$fe$icpsr_issue)),big.mark=","),
                                            format(length(unique(memb_lll$fe$icpsr_issue)),big.mark=","),
                                            format(length(unique(memb3_lll$fe$icpsr_issue)),big.mark=",")),
                                          c("No. Clusters",
                                            format(length(unique(memb_l$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(memb3_l$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(memb_ll$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(memb3_ll$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(memb_lll$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(memb3_lll$clustervar$icpsr)),big.mark=","))),
                         keep.stat = c("n"),font.size = "footnotesize",no.space = T,
                         star.cutoffs = c(0.10,0.05),star.char = c("*","**"),
                         notes.append = FALSE,notes.label = "",column.sep.width="0pt",
                         notes="\\parbox[t]{0.95\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                     standard errors clustered on legislators in parentheses. Observations are at the MC-by-issue-by-Congress level.
                      $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")
  
  cat(tab_ll_sg, sep = '\n', file = "./results/main_ll.tex")

  
###############################
# sample robustness ###########
###############################
  
# next, we'll explore sample robustness by iteratively dropping single values 
# for a few different dimensions of our dataset

# first, committees

  comms <- sort(unique(mc$committee))
  comm_list <- list()
    # create the list of committees and a storage list
  
  for(j in 1:length(comms)){
      # iterate over the committees
    
    bit_comm <- mc[mc$committee!=sort(comms)[j],]
      # remove each committee from the dataset
    
    memb_wo <- felm(adj.score~rpres*on_committee|icpsr_issue+cong_issue|0|icpsr,data=bit_comm)
      # estimate our main model without it
    
    comm_list[[j]] <- summary(memb_wo)$coefficients["rpres:on_committee",]
      # save the interaction
    
  }

  comm_dat <- as.data.frame(do.call(rbind,comm_list))
  comm_dat$committee <- sort(comms)
  comm_dat$committee <- gsub("_"," ",fixed=T,paste(toupper(str_sub(comm_dat$committee,1,1)),str_sub(comm_dat$committee,2),sep=""))
  comm_dat[comm_dat$committee=="Armed services","committee"] <- "Armed Services"
  comm_dat[comm_dat$committee=="Energy commerce","committee"] <- "Energy & Commerce"
  comm_dat[comm_dat$committee=="Educ labor","committee"] <- "Education & Labor"
  comm_dat[comm_dat$committee=="Foreign affairs","committee"] <- "Foreign Affairs"
  comm_dat[comm_dat$committee=="Ways means","committee"] <- "Ways & Means"
    # piece the data together, create a pretty committee variable
  
  # make a plot

    ggplot(comm_dat,aes(x=committee,y=Estimate,ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`))+
      geom_point(size=4)+
      geom_linerange(size=1.25)+
      geom_linerange(aes(x=committee,ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`),size=2)+
      geom_hline(yintercept=0,linetype=2,size=2,colour="grey40")+
      theme_minimal()+
      xlab("Committee")+
      theme(axis.text.x = element_text(angle = 45, hjust = 1))
    
    ggsave("./results/drop_committees.jpeg",width=6,height=4,units="in",dpi=600)

# then, issue areas

  issues <- sort(unique(mc$`Issue Area`))
  issue_list <- list()
  
  for(j in 1:length(issues)){
    
    bit_issue2 <- mc[mc$`Issue Area`!=sort(issues)[j],]
    
    memb_woi <- felm(adj.score~rpres*on_committee|icpsr_issue+cong_issue|0|icpsr,data=bit_issue2)
    
    issue_list[[j]] <- summary(memb_woi)$coefficients["rpres:on_committee",]
    
  }

  issue_dat <- as.data.frame(do.call(rbind,issue_list))
  issue_dat$issue <- sort(issues)
    # less difficult; issue area variable already pretty

  # make plot
  
    ggplot(issue_dat,aes(x=issue,y=Estimate,ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`))+
      geom_point(size=4)+
      geom_linerange(size=1.25)+
      geom_linerange(aes(x=issue,ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`),size=2)+
      geom_hline(yintercept=0,linetype=2,size=2,colour="grey40")+
      theme_minimal()+
      xlab("Issue Area")+
      theme(axis.text.x = element_text(angle = 45, hjust = 1))
  
    ggsave("./results/drop_issues.jpeg",width=6,height=4,units="in",dpi=600)
  
# then, congresses

  congresss <- sort(unique(mc$cong))
  congress_list <- list()

  for(j in 1:length(congresss)){
    
    bit_cong <- mc[mc$cong!=sort(congresss)[j],]
    
    memb_woc <- felm(adj.score~rpres*on_committee|icpsr_issue+cong_issue|0|icpsr,data=bit_cong)
    
    congress_list[[j]] <- summary(memb_woc)$coefficients["rpres:on_committee",]
    
  }

  congress_dat <- as.data.frame(do.call(rbind,congress_list))
  congress_dat$congress <- sort(congresss)

  ggplot(congress_dat,aes(x=congress,y=Estimate,ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`))+
    geom_point(size=4)+
    geom_linerange(size=1.25)+
    geom_linerange(aes(x=congress,ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`),size=2)+
    geom_hline(yintercept=0,linetype=2,size=2,colour="grey40")+
    theme_minimal()+
    xlab("Congress")+
    theme(axis.text.x = element_text(angle = 45, hjust = 1))

  ggsave("./results/drop_congresss.jpeg",width=6,height=4,units="in",dpi=600)

# finally, states    

  states <- sort(unique(mc$state))
  state_list <- list()
  
  for(j in 1:length(states)){
    
    bit <- mc[mc$state!=sort(states)[j],]
    
    memb_wos <- felm(adj.score~rpres*on_committee|icpsr_issue+cong_issue|0|icpsr,data=bit)
    
    state_list[[j]] <- summary(memb_wos)$coefficients["rpres:on_committee",]
    
  }

  state_dat <- as.data.frame(do.call(rbind,state_list))
  state_dat$state <- sort(states)

  ggplot(state_dat,aes(x=state,y=Estimate,ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`))+
    geom_point(size=4)+
    geom_linerange(size=1.25)+
    geom_linerange(aes(x=state,ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`),size=2)+
    geom_hline(yintercept=0,linetype=2,size=2,colour="grey40")+
    theme_minimal()+
    xlab("State")+
    theme(axis.text.x = element_text(angle = 45, hjust = 1,size=6))

  ggsave("./results/drop_states.jpeg",width=8,height=4,units="in",dpi=600)


# descriptives for all of these

  fileConn<-file("./results/n_regressions.tex")
  writeLines(as.character(length(comms)+length(issues)+length(congresss)+length(states)), fileConn)
  close(fileConn)
    # this is just the total number of regressions we're running across these different jackknife iterations

  tot_dat <- rbind(state_dat[,1:4],congress_dat[,1:4],issue_dat[,1:4],comm_dat[,1:4])
    # put together the jackknife data

  fileConn<-file("./results/n05.tex")
  writeLines(as.character(as.english(nrow(tot_dat[tot_dat[,4]>0.05,]))), fileConn)
  close(fileConn)
    # what number aren't statistically significant at p<0.05?
  
  fileConn<-file("./results/n10.tex")
  writeLines(as.character(as.english(nrow(tot_dat[tot_dat[,4]>0.1,]))), fileConn)
  close(fileConn)
    # what number aren't statistically significant at p<0.10?

#########################################################
# alternative approaches to data and estimation #########
#########################################################
  
# first we're going to remake the main table, but limit our sample to 
# issues that can reasonably be called ideological. This is really a sample
# difference, not a measurement difference, but has the spirit of exploring
# how our outcome matters

  id_issues <- c("appropriations","economy","education","labor","welfare","taxes")
    # pick the ideological issues

  dist_id <- felm(adj.score~rpres*on_committee|distid_issue+cong_issue|0|icpsr,data=mc[is.element(mc$issue,c(id_issues)),])
  dist_party_id <- felm(adj.score~rpres*on_committee+rep|distid_issue+cong_issue|0|icpsr,data=mc[is.element(mc$issue,c(id_issues)),])
  memb_id <- felm(adj.score~rpres*on_committee|icpsr_issue+cong_issue|0|icpsr,data=mc[is.element(mc$issue,c(id_issues)),])
  memb2_id <- felm(adj.score~rpres*on_committee-rpres|icpsr_issue+cong_icpsr|0|icpsr,data=mc[is.element(mc$issue,c(id_issues)),])
  memb3_id <- felm(adj.score~rpres*on_committee-rpres|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc[is.element(mc$issue,c(id_issues)),])
    # run the models from our main table, but limiting the issues to these ones
  
  tab_id_sg <- stargazer(memb_id,memb2_id,memb3_id,dist_id,dist_party_id,
                         dep.var.labels = c("Adjusted Conservative Vote Probability"),
                         title="Committee Service and Ideological Responsiveness, Only Ideological Issues",
                         label="main_id",
                         covariate.labels = c("Republican Presidential Vote Share",
                                              "On Committee",
                                              "Republican",
                                              "Rep. Pres. Vote Share $\\times$ On Comm."),
                         add.lines = list(c("Member-by-Issue Fixed Effects","\\checkmark","\\checkmark","\\checkmark","",""),
                                          c("District-by-Issue Fixed Effects","","","","\\checkmark","\\checkmark"),
                                          c("Congress-by-Issue Fixed Effects","\\checkmark","","\\checkmark","\\checkmark","\\checkmark"),
                                          c("Congress-by-Member Fixed Effects","","\\checkmark","\\checkmark","",""),
                                          c("No. Unit FEs",
                                            format(length(unique(memb_id$fe$icpsr_issue)),big.mark=","),
                                            format(length(unique(memb2_id$fe$icpsr_issue)),big.mark=","),
                                            format(length(unique(memb3_id$fe$icpsr_issue)),big.mark=","),
                                            format(length(unique(dist_id$fe$distid_issue)),big.mark=","),
                                            format(length(unique(dist_party_id$fe$distid_issue)),big.mark=",")),
                                          c("No. Clusters",
                                            format(length(unique(memb_id$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(memb2_id$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(memb3_id$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(dist_id$clustervar$icpsr)),big.mark=","),
                                            format(length(unique(dist_party_id$clustervar$icpsr)),big.mark=","))),
                         keep.stat = c("n"),
                         star.cutoffs = c(0.10,0.05),star.char = c("*","**"),table.placement="!ht",
                         notes.append = FALSE,notes.label = "",column.sep.width="0pt",
                         table.layout ="-ld-#-t-as-n",
                         notes="\\parbox[t]{0.95\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                       standard errors clustered on legislators in parentheses. Observations are at the MC-by-issue-by-Congress level.
                        $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")
  
  cat(tab_id_sg, sep = '\n', file = "./results/main_id.tex")

# next we estimate models using the regular (un-adjusted) conservative vote probability measure  
# this should be "wrong" technically, but allows us to show that our results aren't solely
# the product of our adjustments

  dist_cvp <- felm(cvp~rpres*on_committee|distid_issue+cong_issue|0|icpsr,data=mc)
  dist_party_cvp <- felm(cvp~rpres*on_committee+rep|distid_issue+cong_issue|0|icpsr,data=mc)
  memb_cvp <- felm(cvp~rpres*on_committee|icpsr_issue+cong_issue|0|icpsr,data=mc)
  memb2_cvp <- felm(cvp~rpres*on_committee-rpres|icpsr_issue+cong_icpsr|0|icpsr,data=mc)
  memb3_cvp <- felm(cvp~rpres*on_committee-rpres|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc)

  tab_cvp_sg <- stargazer(memb_cvp,memb2_cvp,memb3_cvp,dist_cvp,dist_party_cvp,
                          dep.var.labels = c("Unadjusted Conservative Vote Probability"),
                          title="Committee Service and Ideological Responsiveness: Unadjusted CVP Measure",
                          label="main_cvp",
                          covariate.labels = c("Republican Presidential Vote Share",
                                               "On Committee",
                                               "Republican",
                                               "Rep. Pres. Vote Share $\\times$ On Comm."),
                          add.lines = list(c("Member-by-Issue Fixed Effects","\\checkmark","\\checkmark","\\checkmark","",""),
                                           c("District-by-Issue Fixed Effects","","","","\\checkmark","\\checkmark"),
                                           c("Congress-by-Issue Fixed Effects","\\checkmark","","\\checkmark","\\checkmark","\\checkmark"),
                                           c("Congress-by-Member Fixed Effects","","\\checkmark","\\checkmark","",""),
                                           c("No. Unit FEs",
                                             format(length(unique(memb_cvp$fe$icpsr_issue)),big.mark=","),
                                             format(length(unique(memb2_cvp$fe$icpsr_issue)),big.mark=","),
                                             format(length(unique(memb3_cvp$fe$icpsr_issue)),big.mark=","),
                                             format(length(unique(dist_cvp$fe$distid_issue)),big.mark=","),
                                             format(length(unique(dist_party_cvp$fe$distid_issue)),big.mark=",")),
                                           c("No. Clusters",
                                             format(length(unique(memb_cvp$clustervar$icpsr)),big.mark=","),
                                             format(length(unique(memb2_cvp$clustervar$icpsr)),big.mark=","),
                                             format(length(unique(memb3_cvp$clustervar$icpsr)),big.mark=","),
                                             format(length(unique(dist_cvp$clustervar$icpsr)),big.mark=","),
                                             format(length(unique(dist_party_cvp$clustervar$icpsr)),big.mark=","))),
                          keep.stat = c("n"),
                          star.cutoffs = c(0.10,0.05),star.char = c("*","**"),
                          notes.append = FALSE,notes.label = "",column.sep.width="0pt",table.placement="!ht",
                          notes="\\parbox[t]{0.95\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                       standard errors clustered on legislators in parentheses. Observations are at the MC-by-issue-by-Congress level.
                        $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")
  
  cat(tab_cvp_sg, sep = '\n', file = "./results/main_cvp.tex")
  
# next we estimate models to explore how 'polarization' is affected by committee service
# we continue to include republican presidential vote share as a control variable, but 
# our focus is on the interaction between "republican" and "on_committee"
# note that we don't estimate the second district model including a control for party, 
# since that's kind of now just the main one! we also omit the base term on "republican"
# from all models with member-specific models
  
  dist_pol <- felm(adj.score~on_committee*rep+rpres|distid_issue+cong_issue|0|icpsr,data=mc)
  memb_pol <- felm(adj.score~on_committee*rep+rpres-rep|icpsr_issue+cong_issue|0|icpsr,data=mc)
  memb2_pol <- felm(adj.score~on_committee*rep-rep|icpsr_issue+cong_icpsr|0|icpsr,data=mc)
  memb3_pol <- felm(adj.score~on_committee*rep-rep|icpsr_issue+cong_issue+cong_icpsr|0|icpsr,data=mc)
  
  pol_sg <- stargazer(memb_pol,memb2_pol,memb3_pol,dist_pol,
                      dep.var.labels = c("Adjusted Conservative Vote Probability"),
                      title="Committee Service and Polarization",
                      label="polarization",order=c(1,4,2,3),
                      covariate.labels = c("On Committee","On Commmittee $\\times$ Republican",
                                            "Republican","GOP Pres. Vote Share"),
                      add.lines = list(c("District-by-Issue Fixed Effects","","","","\\checkmark"),
                                       c("Member-by-Issue Fixed Effects","\\checkmark","\\checkmark","\\checkmark",""),
                                       c("Congress-by-Issue Fixed Effects","\\checkmark","","\\checkmark","\\checkmark"),
                                       c("Congress-by-Member Fixed Effects","","\\checkmark","\\checkmark",""),
                                       c("No. Unit FEs",
                                         format(length(unique(memb_pol$fe$icpsr_issue)),big.mark=","),
                                         format(length(unique(memb2_pol$fe$icpsr_issue)),big.mark=","),
                                         format(length(unique(memb3_pol$fe$icpsr_issue)),big.mark=","),
                                         format(length(unique(dist_pol$fe$distid_issue)),big.mark=",")),
                                       c("No. Clusters",
                                         format(length(unique(memb_pol$clustervar$icpsr)),big.mark=","),
                                         format(length(unique(memb2_pol$clustervar$icpsr)),big.mark=","),
                                         format(length(unique(memb3_pol$clustervar$icpsr)),big.mark=","),
                                         format(length(unique(dist_pol$clustervar$icpsr)),big.mark=","))),
                      keep.stat = c("n"),
                      star.cutoffs = c(0.10,0.05),star.char = c("*","**"),table.placement="!ht",
                      notes.append = FALSE,notes.label = "",column.sep.width="0pt",
                      table.layout ="-ld-#-t-as-n",
                      notes="\\parbox[t]{0.8\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                     standard errors clustered on legislators in parentheses. Observations are at the MC-by-issue-by-Congress level.
                      $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")
  
  cat(pol_sg, sep = '\n', file = "./results/polarization.tex")    

####################################
# Heterogeneous Effects ############
####################################
  
# in this section we're going to do a whole lot of looking at heterogeneity across groups
# the basic idea is similar to the heterogeneity across committee type we show above
  
# heterogeneity across parties
  
  memb_party_int_rep <- felm(adj.score~rpres*on_committee*rep-rep|factor(icpsr_issue)+factor(cong_issue)+as.numeric(rep):factor(cong_issue)|0|icpsr,data=mc[mc$rep==1 | mc$dem==1,])
  memb_party_int_dem <- felm(adj.score~rpres*on_committee*dem-dem|factor(icpsr_issue)+factor(cong_issue)+as.numeric(dem):factor(cong_issue)|0|icpsr,data=mc[mc$rep==1 | mc$dem==1,])
    # note that we interact the moderators through the fixed effects whenever possible
    # we also limit the sample to members of the two major parties for this one

  fileConn<-file("./results/party_p.tex")
  writeLines(format(round(summary(memb_party_int_rep)$coefficients["rpres:on_committee:rep","Pr(>|t|)"],3),nsmall=3,big.mark=""), fileConn)
  close(fileConn)
    # save the p-value for the table footer

  rep_base <- summary(memb_party_int_dem)$coefficients["rpres",c("Estimate","Cluster s.e.")]
  dem_base <- summary(memb_party_int_rep)$coefficients["rpres",c("Estimate","Cluster s.e.")]
    # pull out the base terms

  rep_int <- summary(memb_party_int_dem)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
  dem_int <- summary(memb_party_int_rep)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
    # and the interactions -- again, the main two-way one we care about, from the regression
    # where the moderating variable isn't there

  rep_me  <- c(rep_base["Estimate"]+rep_int["Estimate"],
               sqrt(rep_base["Cluster s.e."]^2+rep_int["Cluster s.e."]^2+2*memb_party_int_dem$clustervcv["rpres:on_committee","rpres"]))
  
  dem_me  <- c(dem_base["Estimate"]+dem_int["Estimate"],
               sqrt(dem_base["Cluster s.e."]^2+dem_int["Cluster s.e."]^2+2*memb_party_int_rep$clustervcv["rpres:on_committee","rpres"]))

  party_dat <- as.data.frame(rbind(rep_base,dem_base,rep_int,dem_int,rep_me,dem_me))
  rownames(party_dat) <- NULL
  party_dat$party <- rep(c("Republican","Democrat"),3)
  party_dat$qoi   <- c(rep("Off Committee",2),rep("Difference",2),rep("On Committee",2))
  party_dat$qoi <- factor(party_dat$qoi,levels=c("Off Committee","On Committee","Difference"))
    # put the data together

  # and make the figure
  
    ggplot(data=party_dat,
           aes(x=qoi,y=Estimate,
               ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`,
               colour=party,group=party))+
      geom_hline(yintercept=0,size=1.25,colour="grey40",linetype=2)+
      geom_point(position=position_dodge(width=0.5),size=4)+
      geom_linerange(position=position_dodge(width=0.5),size=1.25)+
      geom_linerange(position=position_dodge(width=0.5),size=2,
                     aes(x=qoi,
                         ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`,
                         colour=party,group=party))+
      scale_colour_grey(start=0.2,end=0.6)+
      xlab("")+
      ylab("Marginal Effect of District GOP Vote Share")+
      labs(color="Party:")+
      theme_minimal()+
      theme(legend.position = "bottom",
            legend.title = element_text(face="bold",size=10),
            legend.text = element_text(face="bold",size=10),
            axis.text = element_text(size=10))
  
    ggsave("./results/party_interaction.jpeg",width=6,height=4,unit="in",dpi=600)

# majority/minority party status

  memb_party_int_maj <- felm(adj.score~rpres*on_committee*maj-maj|factor(icpsr_issue)+factor(cong_issue)+as.numeric(maj):factor(cong_issue)|0|icpsr,data=mc[mc$rep==1 | mc$dem==1,])
  memb_party_int_min <- felm(adj.score~rpres*on_committee*I(1-maj)-I(1-maj)|factor(icpsr_issue)+factor(cong_issue)+as.numeric(I(1-maj)):factor(cong_issue)|0|icpsr,data=mc[mc$rep==1 | mc$dem==1,])
    # again, interacting through, and limiting to major partisans
  
  fileConn<-file("./results/maj_p.tex")
  writeLines(format(round(summary(memb_party_int_maj)$coefficients["rpres:on_committee:maj","Pr(>|t|)"],3),nsmall=3,big.mark=""), fileConn)
  close(fileConn)
    # save the triple interaction p-value

  maj_base <- summary(memb_party_int_min)$coefficients["rpres",c("Estimate","Cluster s.e.")]
  min_base <- summary(memb_party_int_maj)$coefficients["rpres",c("Estimate","Cluster s.e.")]
  
  maj_int <- summary(memb_party_int_min)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
  min_int <- summary(memb_party_int_maj)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]

  maj_me  <- c(maj_base["Estimate"]+maj_int["Estimate"],
               sqrt(maj_base["Cluster s.e."]^2+maj_int["Cluster s.e."]^2+2*memb_party_int_min$clustervcv["rpres:on_committee","rpres"]))
  
  min_me  <- c(min_base["Estimate"]+min_int["Estimate"],
               sqrt(min_base["Cluster s.e."]^2+min_int["Cluster s.e."]^2+2*memb_party_int_maj$clustervcv["rpres:on_committee","rpres"]))

  minmaj_dat <- as.data.frame(rbind(maj_base,min_base,maj_int,min_int,maj_me,min_me))
  rownames(minmaj_dat) <- NULL
  minmaj_dat$party <- rep(c("Majority","Minority"),3)
  minmaj_dat$qoi   <- c(rep("Off Committee",2),rep("Difference",2),rep("On Committee",2))
  minmaj_dat$qoi <- factor(minmaj_dat$qoi,levels=c("Off Committee","On Committee","Difference"))

  ggplot(data=minmaj_dat,
         aes(x=qoi,y=Estimate,
             ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`,
             colour=party,group=party))+
    geom_hline(yintercept=0,size=1.25,colour="grey40",linetype=2)+
    geom_point(position=position_dodge(width=0.5),size=4)+
    geom_linerange(position=position_dodge(width=0.5),size=1.25)+
    geom_linerange(position=position_dodge(width=0.5),size=2,
                   aes(x=qoi,
                       ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`,
                       colour=party,group=party))+
    scale_colour_grey(start=0.2,end=0.6)+
    xlab("")+
    ylab("Marginal Effect of District GOP Vote Share")+
    labs(color="Party:")+
    theme_minimal()+
    theme(legend.position = "bottom",
          legend.title = element_text(face="bold",size=10),
          legend.text = element_text(face="bold",size=10),
          axis.text = element_text(size=10))

  ggsave("./results/majority_interaction.jpeg",width=6,height=4,dpi=600)

# marginality

  memb_party_int_marginal <- felm(adj.score~rpres*on_committee*marginal-marginal|factor(icpsr_issue)+factor(cong_issue)+as.numeric(marginal):(factor(cong_issue))|0|icpsr,data=mc[mc$rep==1 | mc$dem==1,])
  memb_party_int_nonmarginal <- felm(adj.score~rpres*on_committee*I(1-marginal)-I(1-marginal)|factor(icpsr_issue)+factor(cong_issue)+as.numeric(I(1-marginal)):(factor(cong_issue))|0|icpsr,data=mc[mc$rep==1 | mc$dem==1,])

  fileConn<-file("./results/marginality_p.tex")
  writeLines(format(round(summary(memb_party_int_marginal)$coefficients["rpres:on_committee:marginal","Pr(>|t|)"],3),nsmall=3,big.mark=""), fileConn)
  close(fileConn)
  
  marginal_base <- summary(memb_party_int_nonmarginal)$coefficients["rpres",c("Estimate","Cluster s.e.")]
  nonmarginal_base <- summary(memb_party_int_marginal)$coefficients["rpres",c("Estimate","Cluster s.e.")]
  
  marginal_int <- summary(memb_party_int_nonmarginal)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
  nonmarginal_int <- summary(memb_party_int_marginal)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
  
  marginal_me  <- c(marginal_base["Estimate"]+marginal_int["Estimate"],
                    sqrt(marginal_base["Cluster s.e."]^2+marginal_int["Cluster s.e."]^2+2*memb_party_int_nonmarginal$clustervcv["rpres:on_committee","rpres"]))
  
  nonmarginal_me  <- c(nonmarginal_base["Estimate"]+nonmarginal_int["Estimate"],
                       sqrt(nonmarginal_base["Cluster s.e."]^2+nonmarginal_int["Cluster s.e."]^2+2*memb_party_int_marginal$clustervcv["rpres:on_committee","rpres"]))

  safety_dat <- as.data.frame(rbind(marginal_base,nonmarginal_base,marginal_int,nonmarginal_int,marginal_me,nonmarginal_me))
  rownames(safety_dat) <- NULL
  safety_dat$party <- rep(c("Marginal","Safe"),3)
  safety_dat$qoi   <- c(rep("Off Committee",2),rep("Difference",2),rep("On Committee",2))
  safety_dat$qoi   <- factor(safety_dat$qoi,levels=c("Off Committee","On Committee","Difference"))


  ggplot(data=safety_dat,
         aes(x=qoi,y=Estimate,
             ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`,
             colour=party,group=party))+
    geom_hline(yintercept=0,size=1.25,colour="grey40",linetype=2)+
    geom_point(position=position_dodge(width=0.5),size=4)+
    geom_linerange(position=position_dodge(width=0.5),size=1.25)+
    geom_linerange(position=position_dodge(width=0.5),size=2,
                   aes(x=qoi,
                       ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`,
                       colour=party,group=party))+
    scale_colour_grey(start=0.2,end=0.6)+
    xlab("")+
    ylab("Marginal Effect of District GOP Vote Share")+
    labs(color="Time Period:")+
    theme_minimal()+
    theme(legend.position = "bottom",
          legend.title = element_text(face="bold",size=10),
          legend.text = element_text(face="bold",size=10),
          axis.text = element_text(size=10))
  
  ggsave("./results/marginality_interaction.jpeg",width=6,height=4,units="in",dpi=600)
  
# explore heterogeneity over time, specifically whether there are differences before/after
# the Gingrich takeover of the House and consequent reductions in committee staffing and
# centralization of power under the congressional parties
  
  mc$pre <- ifelse(mc$cong<104,1,0)
  
  memb_party_int_pre <- felm(adj.score~rpres*on_committee*pre-pre|factor(icpsr_issue)+factor(cong_issue)|0|icpsr,data=mc)
  memb_party_int_post <- felm(adj.score~rpres*on_committee*I(1-pre)-I(1-pre)|icpsr_issue+cong_issue|0|icpsr,data=mc)
  
  fileConn<-file("./results/time_p.tex")
  writeLines(format(round(summary(memb_party_int_pre)$coefficients["rpres:on_committee:pre","Pr(>|t|)"],3),nsmall=3,big.mark=""), fileConn)
  close(fileConn)
  
  pre_base <- summary(memb_party_int_post)$coefficients["rpres",c("Estimate","Cluster s.e.")]
  post_base <- summary(memb_party_int_pre)$coefficients["rpres",c("Estimate","Cluster s.e.")]
  
  pre_int <- summary(memb_party_int_post)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
  post_int <- summary(memb_party_int_pre)$coefficients["rpres:on_committee",c("Estimate","Cluster s.e.")]
  
  pre_me  <- c(pre_base["Estimate"]+pre_int["Estimate"],
               sqrt(pre_base["Cluster s.e."]^2+pre_int["Cluster s.e."]^2+2*memb_party_int_post$clustervcv["rpres:on_committee","rpres"]))
  
  post_me  <- c(post_base["Estimate"]+post_int["Estimate"],
                sqrt(post_base["Cluster s.e."]^2+post_int["Cluster s.e."]^2+2*memb_party_int_pre$clustervcv["rpres:on_committee","rpres"]))
  
  time_dat <- as.data.frame(rbind(pre_base,post_base,pre_int,post_int,pre_me,post_me))
  rownames(time_dat) <- NULL
  time_dat$party <- rep(c("Before 104th Cong.","104th Cong. and Later"),3)
  time_dat$qoi   <- c(rep("Off Committee",2),rep("Difference",2),rep("On Committee",2))
  time_dat$qoi   <- factor(time_dat$qoi,levels=c("Off Committee","On Committee","Difference"))
  
  ggplot(data=time_dat,
           aes(x=qoi,y=Estimate,
               ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`,
               colour=party,group=party))+
      geom_hline(yintercept=0,size=1.25,colour="grey40",linetype=2)+
      geom_point(position=position_dodge(width=0.5),size=4)+
      geom_linerange(position=position_dodge(width=0.5),size=1.25)+
      geom_linerange(position=position_dodge(width=0.5),size=2,
                     aes(x=qoi,
                         ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`,
                         colour=party,group=party))+
      scale_colour_grey(start=0.2,end=0.6)+
      xlab("")+
      ylab("Marginal Effect of District GOP Vote Share")+
      labs(color="Time Period:")+
      theme_minimal()+
      theme(legend.position = "bottom",
            legend.title = element_text(face="bold",size=10),
            legend.text = element_text(face="bold",size=10),
            axis.text = element_text(size=10))
  
  ggsave("./results/time_interaction.jpeg",width=6,height=4,units="in",dpi=600)

# examine whether the effects of committee service differ depending on the committee
# to do so we interact committee indicators with everything; we also subtract
# the base terms so that we don't have an omitted category to which everything
# would be relative
  
  memb_party_int_comm <- felm(adj.score~rpres*on_committee*factor(committee)-rpres-on_committee-rpres:on_committee-factor(committee)|icpsr_issue+cong_issue|0|icpsr,data=mc)
  memb_party_int_comm_off <- felm(adj.score~rpres*I(1-on_committee)*factor(committee)-rpres-I(1-on_committee)-rpres:I(1-on_committee)-factor(committee)|icpsr_issue+cong_issue|0|icpsr,data=mc)
    # again we estimate two models; this time, it's so that we don't even have to mess
    # with pulling out the interaction term; we just get the marginal effect for
    # on and off for each committee

# now make figure  
  
  comm <- as.data.frame(summary(memb_party_int_comm)$coefficients)
  comm$var <- rownames(comm); rownames(comm) <- NULL
  comm <- comm[grep("rpres",comm$var),]
  comm$qoi <- "Off Committee"
  comm$qoi[grep("on_committee",comm$var)] <- "Difference"
  comm$qoi <- factor(comm$qoi,levels=c("Off Committee","Difference"))

  comm_off <- as.data.frame(summary(memb_party_int_comm_off)$coefficients)
  comm_off$var <- rownames(comm_off); rownames(comm_off) <- NULL
  comm_off <- comm_off[grep("on_committee",comm_off$var,invert=T),]
  comm_off$qoi <- "On Committee"

  comm <- rbind(comm,comm_off)

# make committee names

  comm$committee <- gsub("rpres:","",fixed=T,gsub("factor(committee)","",fixed=T,gsub("on_committee:","",fixed=T,comm$var)))
  comm$committee <- gsub("_"," ",fixed=T,paste(toupper(str_sub(comm$committee,1,1)),str_sub(comm$committee,2),sep=""))
  comm[comm$committee=="Armed services","committee"] <- "Armed Services"
  comm[comm$committee=="Energy commerce","committee"] <- "Energy & Commerce"
  comm[comm$committee=="Educ labor","committee"] <- "Education & Labor"
  comm[comm$committee=="Foreign affairs","committee"] <- "Foreign Affairs"
  comm[comm$committee=="Vet affairs","committee"] <- "Veterans' Affairs"
  comm[comm$committee=="Ways means","committee"] <- "Ways & Means"
  comm$committee <- as.factor(comm$committee)

  comm$qoi <- factor(comm$qoi,levels=c("Off Committee","On Committee","Difference"))

# plot

  ggplot(data=comm,
         aes(x=qoi,y=Estimate,
             ymin=Estimate-2*`Cluster s.e.`,ymax=Estimate+2*`Cluster s.e.`))+
    geom_hline(yintercept=0,size=1.25,colour="grey40",linetype=2)+
    geom_point(position=position_dodge(width=0.5),size=4)+
    geom_linerange(position=position_dodge(width=0.5),size=1.25)+
    geom_linerange(position=position_dodge(width=0.5),size=2,
                   aes(x=qoi,ymin=Estimate-1.65*`Cluster s.e.`,ymax=Estimate+1.65*`Cluster s.e.`))+
    scale_colour_grey(start=0.2,end=0.6)+
    xlab("")+
    ylab("Marginal Effect of District GOP Vote Share")+
    facet_wrap(~committee,ncol=3)+
    theme_bw()+
    theme(strip.background = element_rect(fill="black"),
          strip.text = element_text(face="bold",color="white"))

  ggsave("./results/committee_by_committee.jpeg",width=9.5,height=8.5,units="in",dpi=600)

# finally, explore heterogeneity by committee size

  linear <- felm(adj.score~rpres*on_committee*n_comm_members-n_comm_members|icpsr_issue+cong_issue|0|icpsr,data=mc)
  logged <- felm(adj.score~rpres*on_committee*I(log(n_comm_members))-I(log(n_comm_members))|icpsr_issue+cong_issue|0|icpsr,data=mc)

  size_sg <- stargazer(linear,logged,
                       dep.var.labels = c("Adjusted CVP"),
                       title="Committee Size and Ideological Responsiveness",
                       label="size",
                       covariate.labels = c("Republican Presidential Vote Share",
                                            "On Committee",
                                            "Rep. Vote Share $\\times$ On Comm.",
                                            "Rep Vote Share $\\times$ No. on Committee",
                                            "On Committee $\\times$ No. on Committee",
                                            "Rep. Vote Share $\\times$ On Comm. $\\times$ No. on Committee",

                                            "Rep Vote Share $\\times$ ln(No. on Committee)",
                                            "On Committee $\\times$ ln(No. on Committee)",
                                            "Rep. Vote Share $\\times$ On Comm. $\\times$ ln(No. on Committee)"

                       ),
                       add.lines = list(c("Member-by-Issue Fixed Effects","\\checkmark","\\checkmark"),
                                        c("Congress-by-Issue Fixed Effects","\\checkmark","\\checkmark"),
                                        c("No. Unit FEs",
                                          format(length(unique(linear$fe$icpsr_issue)),big.mark=","),
                                          format(length(unique(logged$fe$icpsr_issue)),big.mark=",")),
                                        c("No. Clusters",
                                          format(length(unique(linear$clustervar$icpsr)),big.mark=","),
                                          format(length(unique(logged$clustervar$icpsr)),big.mark=","))),
                       keep.stat = c("n"),
                       star.cutoffs = c(0.10,0.05),star.char = c("*","**"),
                       notes.append = FALSE,notes.label = "",column.sep.width="0pt",
                       no.space=T,
                       notes="\\parbox[t]{0.8\\textwidth}{\\footnotesize \\textit{Note}: Entries are linear regression coefficients with 
                       standard errors clustered on legislators in parentheses. Observations are at the MC-by-issue-by-Congress level. 
                              $^{*}$p$<$0.10, $^{**}$p$<$0.05 (two-tailed test).}")
  
  cat(size_sg, sep = '\n', file = "./results/size.tex")






